@@ -32,7 +32,9 @@ class VPNServer:
     """
 
     def __init__(self, aws_access_key: str = environ.get('ACCESS_KEY'), aws_secret_key: str = environ.get('SECRET_KEY'),
-                 aws_region_name: str = environ.get('REGION_NAME', 'us-west-2'), log: str = 'CONSOLE'):
+                 aws_region_name: str = environ.get('REGION_NAME', 'us-west-2'), log: str = 'CONSOLE',
+                 gmail_user: str = environ.get('gmail_user'), gmail_pass: str = environ.get('gmail_pass'),
+                 phone: str = environ.get('phone'), recipient: str = environ.get('recipient')):
         """Assigns a name to the PEM file, initiates the logger, client and resource for EC2 using ``boto3`` module.
 
         Args:
@@ -40,6 +42,10 @@ class VPNServer:
             aws_secret_key: Secret ID for AWS account.
             aws_region_name: Region where the instance should live. Defaults to ``us-west-2``
             log: Determines whether to print the log in a console or send it to a file.
+            gmail_user: Gmail username or email address.
+            gmail_pass: Gmail password.
+            phone: Phone number to which an SMS notification has to be sent.
+            recipient: Email address to which an email notification has to be sent.
 
         See Also:
             - If no values (for aws authentication) are passed during object initialization, script checks for env vars.
@@ -55,10 +61,10 @@ class VPNServer:
             self.logger = hybrid_logger
 
         # Notification information
-        self.gmail_user = environ.get('gmail_user')
-        self.gmail_pass = environ.get('gmail_pass')
-        self.recipient = environ.get('recipient')
-        self.phone = environ.get('phone')
+        self.gmail_user = gmail_user
+        self.gmail_pass = gmail_pass
+        self.recipient = recipient
+        self.phone = phone
 
         # AWS client and resource setup
         self.region = aws_region_name.lower()
@@ -100,7 +106,7 @@ class VPNServer:
         Args:
             sleep_time: Takes the time script has to sleep, as an argument.
         """
-        if str(self.logger) == '<Logger FILE (INFO)>':
+        if 'FILE' in str(self.logger):
             self.logger.info(f'Waiting for {sleep_time} seconds.')
             sleep(sleep_time)
             return
@@ -331,9 +337,9 @@ class VPNServer:
 
         if response.get('ResponseMetadata').get('HTTPStatusCode') == 200:
             self.logger.info('OpenVPN has been deleted from KeyPairs.')
-            if path.exists('OpenVPN.pem'):
-                chmod('OpenVPN.pem', int('700', base=8) or 0o700)  # reset file permissions before deleting
-                remove('OpenVPN.pem')
+            if path.exists(f'{CURRENT_DIR}OpenVPN.pem'):
+                chmod(f'{CURRENT_DIR}OpenVPN.pem', int('700', base=8) or 0o700)
+                remove(f'{CURRENT_DIR}OpenVPN.pem')
             return True
         else:
             self.logger.error('Failed to delete the key: OpenVPN')
@@ -399,9 +405,9 @@ class VPNServer:
             A tuple object of Public DNS Name and Public IP Address.
         """
         self.logger.info('Waiting for the instance to go live.')
-        self._sleeper(sleep_time=15)
+        self._sleeper(sleep_time=25)
         while True:
-            sleep(3)
+            self._sleeper(sleep_time=3)
             try:
                 response = self.ec2_client.describe_instance_status(
                     InstanceIds=[instance_id]
@@ -450,6 +456,7 @@ class VPNServer:
         try:
             url_check = requests.get(url=f"https://{data.get('public_ip')}:{self.port}", verify=False)
         except requests.ConnectionError:
+            self.logger.error('Unable to connect the VPN server. Please check the logs for more information.')
             return False
 
         self.logger.info(f"Testing SSH connection to {data.get('public_dns')}")
@@ -459,19 +466,22 @@ class VPNServer:
             self.logger.info(f"Connection to https://{data.get('public_ip')}:{self.port} and "
                              f"SSH to {data.get('public_dns')} was successful.")
             return True
+        else:
+            self.logger.error('Unable to establish SSH connection with the VPN server. '
+                              'Please check the logs for more information.')
+            return False
 
-    def reconfigure_vpn(self):
+    def reconfigure_vpn(self) -> None:
         """Runs the configuration on an existing VPN server."""
         if path.isfile(f'{CURRENT_DIR}vpn_info.json') and path.isfile(f'{CURRENT_DIR}OpenVPN.pem'):
             with open(f'{CURRENT_DIR}vpn_info.json') as file:
                 data_exist = load(file)
             self._configure_vpn(data=data_exist)
-            if not self._tester(data=data_exist):
-                self.logger.error('Unable to connect VPN server. Please check the logs for more information.')
+            self._tester(data=data_exist)
         else:
             self.logger.error('Input file: vpn_info.json is missing. CANNOT proceed.')
 
-    def test_vpn(self):
+    def test_vpn(self) -> None:
         """Tests the ``GET`` and ``SSH`` connections to an existing VPN server."""
         if path.isfile(f'{CURRENT_DIR}vpn_info.json') and path.isfile(f'{CURRENT_DIR}OpenVPN.pem'):
             with open(f'{CURRENT_DIR}vpn_info.json') as file:
@@ -533,7 +543,7 @@ class VPNServer:
             dump(instance_info, file, indent=2)
 
         self.logger.info('Restricting wide open permissions to OpenVPN.pem')
-        chmod('OpenVPN.pem', int('400', base=8) or 0o400)
+        chmod(f'{CURRENT_DIR}OpenVPN.pem', int('400', base=8) or 0o400)
 
         self.logger.info('Waiting for SSH origin to be active.')
         self._sleeper(sleep_time=15)
@@ -570,20 +580,20 @@ class VPNServer:
         vpn_password = environ.get('VPN_PASSWORD', 'awsVPN2021')
 
         configuration = {
-            "> Please enter 'yes' to indicate your agreement [no]: ": "yes",
-            "> Press ENTER for default [yes]: ": "yes",
-            "> Press Enter for default [1]: ": "1",
-            "Please specify the port number for the Admin Web UI.": [str(self.port)],
-            "Please specify the TCP port number for the OpenVPN Daemon.": "443",
-            "Should client traffic be routed by default through the VPN?": "yes",
-            "Should client DNS traffic be routed by default through the VPN?": "no",
-            "Use local authentication via internal DB?": "yes",
-            "Should private subnets be accessible to clients by default?": "yes",
-            "Do you wish to login to the Admin UI as 'openvpn'?": "no",
-            "Specify the username for an existing user or for the new user account:": [vpn_username],
-            f"Type the password for the '{vpn_username}' account:": [vpn_password],
-            f"Confirm the password for the '{vpn_username}' account:": [vpn_password],
-            "Please specify your Activation key (or leave blank to specify later):": "\n"
+            "1|Please enter 'yes' to indicate your agreement \\[no\\]: ": ("yes", 10),
+            "2|> Press ENTER for default \\[yes\\]: ": ("yes", 2),
+            "3|> Press Enter for default \\[1\\]: ": ("1", 2),
+            "4|> Press ENTER for default \\[943\\]: ": [str(self.port), 2],
+            "5|> Press ENTER for default \\[443\\]: ": ("443", 2),
+            "6|> Press ENTER for default \\[no\\]: ": ("yes", 2),
+            "7|> Press ENTER for default \\[no\\]: ": ("no", 2),
+            "8|> Press ENTER for default \\[yes\\]: ": ("yes", 2),
+            "9|> Press ENTER for EC2 default \\[yes\\]: ": ("yes", 2),
+            "10|> Press ENTER for default \\[yes\\]: ": ("no", 2),
+            "11|> Specify the username for an existing user or for the new user account: ": [vpn_username, 2],
+            f"12|Type the password for the '{vpn_username}' account:": [vpn_password, 2],
+            f"13|Confirm the password for the '{vpn_username}' account:": [vpn_password, 2],
+            "14|> Please specify your Activation key \\(or leave blank to specify later\\): ": ("\n", 2)
         }
 
         interactive_ssh(hostname=data.get('public_dns'),
@@ -613,7 +623,7 @@ class VPNServer:
 
         if self.recipient:
             email_response = SendEmail(gmail_user=self.gmail_user, gmail_pass=self.gmail_pass, recipient=self.recipient,
-                                       subject=subject, body=login_details).send_email()
+                                       subject=subject, body=login_details, sender='VPNServer').send_email()
             self._notification_response(response=email_response)
         else:
             self.logger.warning('ENV vars are not configured for an email notification.')
@@ -623,9 +633,6 @@ class VPNServer:
 
         Args:
             partial: Flag to indicate whether the ``SecurityGroup`` has to be removed.
-
-        See Also:
-            There is a wait time (60 seconds) for the instance to terminate.
         """
         if not path.exists('vpn_info.json'):
             self.logger.error('Input file: vpn_info.json is missing. CANNOT proceed.')
@@ -636,7 +643,7 @@ class VPNServer:
 
         if self._delete_key_pair() and self._terminate_ec2_instance(instance_id=data.get('instance_id')):
             if partial:
-                remove('vpn_info.json')
+                remove(f'{CURRENT_DIR}vpn_info.json')
                 return
             self.logger.info('Waiting for dependents to release before deleting SecurityGroup.')
             self._sleeper(sleep_time=90)
@@ -645,4 +652,4 @@ class VPNServer:
                     break
                 else:
                     self._sleeper(sleep_time=20)
-            remove('vpn_info.json')
+            remove(f'{CURRENT_DIR}vpn_info.json')
